@@ -31,8 +31,7 @@
 #' }
 
 get_playlists <- function (filter = NULL,
-                          part = c("contentDetails", "id", "localizations",
-                                   "player", "snippet", "status"),
+                          part = "snippet",
                           max_results = 50, hl = NULL,
                           page_token = NULL, simplify = TRUE, ...) {
 
@@ -51,8 +50,6 @@ get_playlists <- function (filter = NULL,
                                                       names(translate_filter))])
   names(filter)      <- yt_filter_name
 
-  part      <- match.arg(part)
-
   querylist <- list(part = part, maxResults = max_results,
                    pageToken = page_token, hl = hl)
   querylist <- c(querylist, filter)
